diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/__init__.py
new file mode 100644
index 0000000..ca3db01
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/__init__.py
@@ -0,0 +1,872 @@
+##########################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2016, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##########################################################################
+import json
+import re
+from flask import render_template, make_response, request, jsonify
+from flask.ext.babel import gettext
+from pgadmin.utils.ajax import make_json_response, \
+    make_response as ajax_response, internal_server_error
+from pgadmin.browser.utils import PGChildNodeView
+from pgadmin.browser.collection import CollectionNodeModule
+import pgadmin.browser.server_groups.servers as servers
+from pgadmin.utils.ajax import precondition_required
+from pgadmin.utils.driver import get_driver
+from config import PG_DEFAULT_DRIVER
+from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
+    parse_priv_to_db
+from functools import wraps
+
+"""
+    This module is responsible for generating two nodes
+    1) Schemas
+    2) Catalogs
+
+    We have created single file because catalog & schema has same functionality,
+    the only difference is we can not perform DDL/DML operations on
+    catalogs.
+
+    This modules uses separate template paths for each respective node
+    - templates/catalogs for Catalog node
+    - templates/schemas for Schema node
+
+    [ Each path contains node specific js files as well as sql
+    template files]
+"""
+
+
+class SchemaModule(CollectionNodeModule):
+    NODE_TYPE = 'schema'
+    COLLECTION_LABEL = gettext("Schemas")
+
+    def __init__(self, *args, **kwargs):
+        self.min_ver = None
+        self.max_ver = None
+
+        super(SchemaModule, self).__init__(*args, **kwargs)
+
+    def get_nodes(self, gid, sid, did):
+        """
+        Generate the collection node
+        """
+        yield self.generate_browser_collection_node(did)
+
+    @property
+    def script_load(self):
+        """
+        Load the module script for server, when any of the server-group node is
+        initialized.
+        """
+        return servers.ServerModule.NODE_TYPE
+
+blueprint = SchemaModule(__name__)
+
+
+class SchemaView(PGChildNodeView):
+    """
+    This class is responsible for generating schemas node
+    All the schema related routes/views are defied in this class
+    """
+    node_type = blueprint.node_type
+
+    parent_ids = [
+            {'type': 'int', 'id': 'gid'},
+            {'type': 'int', 'id': 'sid'},
+            {'type': 'int', 'id': 'did'}
+            ]
+    ids = [
+            {'type': 'int', 'id': 'scid'}
+            ]
+
+    operations = dict({
+        'obj': [
+            {'get': 'properties', 'delete': 'delete', 'put': 'update'},
+            {'get': 'list', 'post': 'create'}
+        ],
+        'children': [{
+            'get': 'children'
+        }],
+        'nodes': [{'get': 'node'}, {'get': 'nodes'}],
+        'sql': [{'get': 'sql'}],
+        'msql': [{'get': 'msql'}, {'get': 'msql'}],
+        'stats': [{'get': 'statistics'}],
+        'dependency': [{'get': 'dependencies'}],
+        'dependent': [{'get': 'dependents'}],
+        'module.js': [{}, {}, {'get': 'module_js'}],
+        'delete': [{'delete': 'delete'}]
+    })
+
+    def module_js(self):
+        """
+        This property defines (if javascript) exists for this node.
+        Override this property for your own logic.
+        """
+        return make_response(
+                render_template(
+                    "schemas/js/schemas.js",
+                    _=gettext
+                    ),
+                200, {'Content-Type': 'application/x-javascript'}
+                )
+
+    def check_precondition(f):
+        """
+        This function will behave as a decorator which will checks
+        database connection before running view, it will also attaches
+        manager,conn & template_path properties to self
+        """
+        @wraps(f)
+        def wrap(*args, **kwargs):
+            # Here args[0] will hold self & kwargs will hold gid,sid,did
+            self = args[0]
+            self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(
+                kwargs['sid']
+            )
+            self.conn = self.manager.connection(did=kwargs['did'])
+            # If DB not connected then return error to browser
+            if not self.conn.connected():
+                return precondition_required(
+                    gettext(
+                            "Connection to the server has been lost!"
+                    )
+                )
+
+            ver = self.manager.version
+            server_type = self.manager.server_type
+            # we will set template path for sql scripts
+            # For EDB PPAS
+            if server_type == 'ppas' and ver >= 90200:
+                self.template_path = 'schemas/sql/edb_9.2_plus'
+            elif server_type == 'ppas' and ver >= 90100:
+                self.template_path = 'schemas/sql/edb_9.1_plus'
+            elif server_type == 'ppas' and ver <= 90100:
+                self.template_path = 'schemas/sql/edb_pre_9.1'
+            # For Postgres
+            elif ver >= 90200:
+                self.template_path = 'schemas/sql/9.2_plus'
+            elif ver >= 90100:
+                self.template_path = 'schemas/sql/9.1_plus'
+            else:
+                self.template_path = 'schemas/sql/pre_9.1'
+
+            return f(*args, **kwargs)
+
+        return wrap
+
+    @staticmethod
+    def formatdbacl(acl):
+        """
+        Args:
+            acl: Privileges from ACL query
+
+        Returns:
+            Formatted output required for client side parsing
+        """
+        # Reset any data for that acl if its already present in result set
+        data = dict()
+        for row in acl['rows']:
+            priv = parse_priv_from_db(row)
+            if row['deftype'] in data:
+                data[row['deftype']].append(priv)
+            else:
+                data[row['deftype']] = [priv]
+        return data
+
+    def _formatter(self, data, scid=None):
+        """
+        Args:
+            data: Result of properties query
+            scid: Schema OID
+
+        Returns:
+            It will return formatted output of collections like
+            security lables, privileges
+        """
+        # Need to format security labels according to client js collection
+        seclabels = []
+        if 'seclabels' in data and data['seclabels'] is not None:
+            for sec in data['seclabels']:
+                sec = re.search(r'([^=]+)=(.*$)', sec)
+                seclabels.append({
+                    'provider': sec.group(1),
+                    'security_label': sec.group(2)
+                    })
+
+        data['seclabels'] = seclabels
+
+        # We need to parse & convert ACL coming from database to json format
+        SQL = render_template("/".join([self.template_path, 'acl.sql']),
+                              scid=scid)
+        status, acl = self.conn.execute_dict(SQL)
+        if not status:
+            return internal_server_error(errormsg=acl)
+
+        data.update(self.formatdbacl(acl))
+
+        # Default privilege is only supported if PG version minimum 9.1
+        if self.manager.version >= 90100:
+            # We need to parse & convert DEFAULT ACL coming from
+            # database to json format
+            SQL = render_template("/".join([self.template_path, 'defacl.sql']),
+                                  scid=scid)
+            status, defacl = self.conn.execute_dict(SQL)
+            if not status:
+                return internal_server_error(errormsg=defacl)
+
+            data.update(self.formatdbacl(defacl))
+
+        return data
+
+    @check_precondition
+    def list(self, gid, sid, did):
+        SQL = render_template("/".join([self.template_path, 'properties.sql']))
+        status, res = self.conn.execute_dict(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=res)
+        return ajax_response(
+                response=res['rows'],
+                status=200
+                )
+
+    @check_precondition
+    def nodes(self, gid, sid, did):
+        res = []
+        SQL = render_template("/".join([self.template_path, 'properties.sql']))
+        status, rset = self.conn.execute_2darray(SQL)
+        if not status:
+            return internal_server_error(errormsg=rset)
+
+        for row in rset['rows']:
+            res.append(
+                    self.blueprint.generate_browser_node(
+                        row['oid'],
+                        did,
+                        row['name'],
+                        icon="icon-schema"
+                    ))
+
+        return make_json_response(
+                data=res,
+                status=200
+                )
+
+    @check_precondition
+    def properties(self, gid, sid, did, scid):
+        SQL = render_template("/".join([self.template_path,
+                                        'properties.sql']), scid=scid)
+        status, res = self.conn.execute_dict(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=res)
+
+        # Making copy of output for future use
+        copy_data = dict(res['rows'][0])
+        copy_data = self._formatter(copy_data, scid)
+
+        return ajax_response(
+                response=copy_data,
+                status=200
+                )
+
+    @check_precondition
+    def create(self, gid, sid, did):
+        """
+        This function will creates new the schema object
+        """
+        data = request.form if request.form else \
+            json.loads(request.data.decode())
+
+        required_args = {
+            'name': 'Name'
+        }
+
+        for arg in required_args:
+            if arg not in data:
+                return make_json_response(
+                    status=410,
+                    success=0,
+                    errormsg=gettext(
+                        "Couldn't find the required parameter (%s)." %
+                        required_args[arg]
+                    )
+                )
+        try:
+            SQL = render_template("/".join([self.template_path, 'create.sql']),
+                                  data=data, conn=self.conn)
+            status, res = self.conn.execute_scalar(SQL)
+            if not status:
+                return make_json_response(
+                    status=410,
+                    success=0,
+                    errormsg=res + '\n' +
+                    'Operation failed while running create statement'
+                    )
+
+            if 'nspacl' in data:
+                data['nspacl'] = parse_priv_to_db(data['nspacl'], 'SCHEMA')
+
+            SQL = render_template("/".join([self.template_path, 'alter.sql']),
+                                  data=data, conn=self.conn)
+            # Checking if we are not executing empty query
+            if SQL and SQL.strip('\n') and SQL.strip(' '):
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return make_json_response(
+                        status=410,
+                        success=0,
+                        errormsg=res + '\n' +
+                        'Operation failed while running alter statement'
+                        )
+
+            # we need oid to to add object in tree at browser,
+            # below sql will gives the same
+            SQL = render_template("/".join([self.template_path, 'alter.sql']),
+                                  schema=data['name'])
+            status, scid = self.conn.execute_scalar(SQL)
+            if not status:
+                return internal_server_error(errormsg=scid)
+
+            return jsonify(
+                node=self.blueprint.generate_browser_node(
+                    scid,
+                    did,
+                    data['name'],
+                    icon="icon-schema"
+                )
+            )
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
+    @check_precondition
+    def update(self, gid, sid, did, scid):
+        """
+        This function will update schema object
+        """
+        data = request.form if request.form else json.loads(
+            request.data.decode()
+        )
+        try:
+            SQL = self.getSQL(gid, sid, data, scid)
+
+            if SQL and SQL.strip('\n') and SQL.strip(' '):
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
+
+                return make_json_response(
+                    success=1,
+                    info="Schema updated",
+                    data={
+                        'id': scid,
+                        'sid': sid,
+                        'gid': gid,
+                        'did': did
+                    }
+                )
+            else:
+                return make_json_response(
+                    success=1,
+                    info="Nothing to update",
+                    data={
+                        'id': scid,
+                        'sid': sid,
+                        'gid': gid,
+                        'did': did
+                    }
+                )
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
+    @check_precondition
+    def delete(self, gid, sid, did, scid):
+        """
+        This function will drop the schema object
+        """
+        # Below will decide if it's simple drop or drop with cascade call
+        if self.cmd == 'delete':
+            # This is a cascade operation
+            cascade = True
+        else:
+            cascade = False
+
+        try:
+            # Get name for schema from did
+            SQL = render_template("/".join([self.template_path,
+                                            'delete.sql']), scid=scid)
+            status, name = self.conn.execute_scalar(SQL)
+            if not status:
+                return internal_server_error(errormsg=name)
+            # drop schema
+            SQL = render_template("/".join([self.template_path, 'delete.sql']),
+                                  name=name, cascade=cascade, conn=self.conn)
+            status, res = self.conn.execute_scalar(SQL)
+            if not status:
+                return internal_server_error(errormsg=res)
+
+            return make_json_response(
+                success=1,
+                info=gettext("Schema dropped"),
+                data={
+                    'id': scid,
+                    'sid': sid,
+                    'gid': gid,
+                    'did': did
+                }
+            )
+
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
+    @check_precondition
+    def msql(self, gid, sid, did, scid=None):
+        """
+        This function to return modified SQL
+        """
+        data = dict()
+        for k, v in request.args.items():
+            try:
+                data[k] = json.loads(v)
+            except ValueError:
+                data[k] = v
+
+        try:
+            SQL = self.getSQL(gid, sid, data, scid)
+            if SQL and SQL.strip('\n') and SQL.strip(' '):
+                return make_json_response(
+                        data=SQL,
+                        status=200
+                        )
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
+    def getSQL(self, gid, sid, data, scid=None):
+        """
+        This function will generate sql from model data received from client
+        """
+        if scid is not None:
+            SQL = render_template("/".join([self.template_path,
+                                            'properties.sql']), scid=scid)
+            status, res = self.conn.execute_dict(SQL)
+            if not status:
+                return internal_server_error(errormsg=res)
+            old_data = res['rows'][0]
+            # old_data contains all the existing data for requested schema
+            old_data = self._formatter(old_data, scid)
+
+            # if name is not present in request data then use old name
+            if 'name' not in data:
+                data['name'] = old_data['name']
+
+            # Privileges
+            for key in ['nspacl']:
+                if key in data and data[key] is not None:
+                    if 'added' in data[key]:
+                      data[key]['added'] = parse_priv_to_db(
+                          data[key]['added'], 'SCHEMA'
+                      )
+                    if 'changed' in data[key]:
+                      data[key]['changed'] = parse_priv_to_db(
+                          data[key]['changed'], 'SCHEMA'
+                      )
+                    if 'deleted' in data[key]:
+                      data[key]['deleted'] = parse_priv_to_db(
+                          data[key]['deleted'], 'SCHEMA'
+                      )
+
+            # Default privileges
+            for key in ['deftblacl', 'defseqacl', 'deffuncacl', 'deftypeacl']:
+                if key in data and data[key] is not None:
+                    if 'added' in data[key]:
+                      data[key]['added'] = parse_priv_to_db(
+                          data[key]['added']
+                      )
+                    if 'changed' in data[key]:
+                      data[key]['changed'] = parse_priv_to_db(
+                          data[key]['changed']
+                      )
+                    if 'deleted' in data[key]:
+                      data[key]['deleted'] = parse_priv_to_db(
+                          data[key]['deleted']
+                      )
+
+            SQL = render_template(
+                "/".join([self.template_path, 'update.sql']),
+                data=data, o_data=old_data, conn=self.conn
+                )
+        else:
+            required_args = [
+                'name'
+            ]
+
+            for arg in required_args:
+                if arg not in data:
+                    return " -- definition incomplete",
+
+            # Privileges
+            if 'nspacl' in data and data['nspacl'] is not None:
+                data['nspacl'] = parse_priv_to_db(data['nspacl'], 'SCHEMA')
+
+            SQL = render_template("/".join([self.template_path, 'create.sql'])
+                                  , data=data, conn=self.conn)
+            SQL += "\n"
+            SQL += render_template("/".join([self.template_path, 'alter.sql'])
+                                   , data=data, conn=self.conn)
+
+        return SQL
+
+    @check_precondition
+    def sql(self, gid, sid, did, scid):
+        """
+        This function will genrate sql for sql panel
+        """
+        SQL = render_template("/".join([self.template_path,
+                                        'properties.sql']), scid=scid)
+        status, res = self.conn.execute_dict(SQL)
+        if not status:
+            return internal_server_error(errormsg=res)
+
+        old_data = res['rows'][0]
+        old_data = self._formatter(old_data, scid)
+
+        # Privileges
+        if 'nspacl' in old_data and old_data['nspacl'] is not None:
+            old_data['nspacl'] = parse_priv_to_db(old_data['nspacl'], 'SCHEMA')
+
+        # Default privileges
+        for key in ['deftblacl', 'defseqacl', 'deffuncacl', 'deftypeacl']:
+            if key in old_data and old_data[key] is not None:
+                old_data[key] = parse_priv_to_db(old_data[key])
+
+        # Render sql from create & alter sql using properties & acl data
+        SQL = ''
+        SQL = render_template("/".join([self.template_path, 'create.sql']),
+                              data=old_data, conn=self.conn)
+        SQL += "\n"
+        SQL += render_template("/".join([self.template_path, 'alter.sql']),
+                               data=old_data, conn=self.conn)
+
+        sql_header = """
+-- SCHEMA: {0};
+
+-- DROP SCHEMA {0};
+
+""".format(old_data['name'])
+
+        SQL = sql_header + SQL
+
+        return ajax_response(response=SQL)
+
+SchemaView.register_node_view(blueprint)
+
+
+class CatalogModule(CollectionNodeModule):
+    NODE_TYPE = 'catalog'
+    COLLECTION_LABEL = gettext("Catalogs")
+
+    def __init__(self, *args, **kwargs):
+        self.min_ver = None
+        self.max_ver = None
+
+        super(CatalogModule, self).__init__(*args, **kwargs)
+
+    def get_nodes(self, gid, sid, did):
+        """
+        Generate the collection node
+        """
+        yield self.generate_browser_collection_node(did)
+
+    @property
+    def script_load(self):
+        """
+        Load the module script for server, when any of the server-group node is
+        initialized.
+        """
+        return servers.ServerModule.NODE_TYPE
+
+catalog_blueprint = CatalogModule(__name__)
+
+
+class CatalogView(PGChildNodeView):
+    """
+    This class is responsible for generating catalogs node
+    All the catalog related routes/views are defied in this class
+    """
+
+    node_type = catalog_blueprint.node_type
+
+    parent_ids = [
+        {'type': 'int', 'id': 'gid'},
+        {'type': 'int', 'id': 'sid'},
+        {'type': 'int', 'id': 'did'}
+        ]
+    ids = [
+                    {'type': 'int', 'id': 'scid'}
+            ]
+
+    operations = dict({
+        'obj': [
+            {'get': 'properties', 'delete': 'delete', 'put': 'update'},
+            {'get': 'list', 'post': 'create'}
+        ],
+        'children': [{'get': 'children'}],
+        'nodes': [{'get': 'node'}, {'get': 'nodes'}],
+        'sql': [{'get': 'sql'}],
+        'msql': [{'get': 'msql'}, {'get': 'msql'}],
+        'stats': [{'get': 'statistics'}],
+        'dependency': [{'get': 'dependencies'}],
+        'dependent': [{'get': 'dependents'}],
+        'module.js': [{}, {}, {'get': 'module_js'}],
+        'configs': [{'get': 'configs'}]
+    })
+
+    def module_js(self):
+        """
+        This property defines (if javascript) exists for this node.
+        Override this property for your own logic.
+        """
+        return make_response(
+                render_template(
+                    "catalogs/js/catalogs.js",
+                    _=gettext
+                    ),
+                200, {'Content-Type': 'application/x-javascript'}
+                )
+
+    def check_precondition(f):
+        """
+        This function will behave as a decorator which will checks
+        database connection before running view, it will also attaches
+        manager,conn & template_path properties to self
+        """
+        @wraps(f)
+        def wrap(*args, **kwargs):
+            # Here args[0] will hold self & kwargs will hold gid,sid,did
+            self = args[0]
+            self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(kwargs['sid'])
+            self.conn = self.manager.connection()
+
+            # If DB not connected then return error to browser
+            if not self.conn.connected():
+                return precondition_required(
+                    gettext(
+                            "Connection to the server has been lost!"
+                    )
+                )
+
+            ver = self.manager.version
+            server_type = self.manager.server_type
+            # we will set template path for sql scripts
+            # For EDB PPAS
+            if server_type == 'ppas' and ver >= 90200:
+                self.template_path = 'catalogs/sql/edb_9.2_plus'
+            elif server_type == 'ppas' and ver >= 90100:
+                self.template_path = 'catalogs/sql/edb_9.1_plus'
+            elif server_type == 'ppas' and ver <= 90100:
+                self.template_path = 'catalogs/sql/edb_pre_9.1'
+            # For Postgres
+            elif ver >= 90200:
+                self.template_path = 'catalogs/sql/9.2_plus'
+            elif ver >= 90100:
+                self.template_path = 'catalogs/sql/9.1_plus'
+            else:
+                self.template_path = 'catalogs/sql/pre_9.1'
+
+            return f(*args, **kwargs)
+
+        return wrap
+
+
+    @check_precondition
+    def list(self, gid, sid, did):
+        SQL = render_template("/".join([self.template_path, 'properties.sql']))
+        status, res = self.conn.execute_dict(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=res)
+        return ajax_response(
+                response=res['rows'],
+                status=200
+                )
+
+    @check_precondition
+    def nodes(self, gid, sid, did):
+        res = []
+        SQL = render_template("/".join([self.template_path, 'properties.sql']))
+        status, rset = self.conn.execute_2darray(SQL)
+        if not status:
+            return internal_server_error(errormsg=rset)
+
+        for row in rset['rows']:
+            res.append(
+                    self.blueprint.generate_browser_node(
+                        row['oid'],
+                        did,
+                        row['name'],
+                        icon="icon-catalog"
+                    ))
+
+        return make_json_response(
+                data=res,
+                status=200
+                )
+
+    @check_precondition
+    def properties(self, gid, sid, did, scid):
+        SQL = render_template("/".join([self.template_path, 'properties.sql']),
+                              cid=scid)
+        status, res = self.conn.execute_dict(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=res)
+        data = dict(res['rows'][0])
+
+        seclabels = []
+        if 'seclabels' in data and data['seclabels'] is not None:
+            for sec in data['seclabels']:
+                sec = re.search(r'([^=]+)=(.*$)', sec)
+                seclabels.append({
+                    'provider': sec.group(1),
+                    'security_label': sec.group(2)
+                    })
+
+        data['seclabels'] = seclabels
+
+
+        return ajax_response(
+                response=data,
+                status=200
+                )
+
+    @check_precondition
+    def update(self, gid, sid, did, scid):
+        """
+        This function will update tablespace object
+        """
+        data = request.form if request.form else json.loads(request.data.decode())
+
+        try:
+            SQL = self.getSQL(gid, sid, data, scid)
+            if SQL and SQL.strip('\n') and SQL.strip(' '):
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
+
+                return make_json_response(
+                    success=1,
+                    info="Catalog updated",
+                    data={
+                        'id': scid,
+                        'sid': sid,
+                        'gid': gid,
+                        'did': did
+                    }
+                )
+            else:
+                return make_json_response(
+                    success=1,
+                    info="Nothing to update",
+                    data={
+                        'id': scid,
+                        'sid': sid,
+                        'gid': gid,
+                        'did': did
+                    }
+                )
+
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
+    @check_precondition
+    def msql(self, gid, sid, did, scid):
+        """
+        This function to return modified SQL
+        """
+        data = dict()
+        # Converting it into json format
+        for k, v in request.args.items():
+            try:
+                data[k] = json.loads(v)
+            except ValueError:
+                data[k] = v
+
+        try:
+            SQL = self.getSQL(gid, sid, data, scid)
+            if SQL and SQL.strip('\n') and SQL.strip(' '):
+                return make_json_response(
+                        data=SQL,
+                        status=200
+                )
+        except Exception as e:
+            return internal_server_error(errormsg=str(e))
+
+    def getSQL(self, gid, sid, data, scid=None):
+        """
+        This function will genrate sql from model data
+        """
+        if scid is not None:
+            SQL = render_template("/".join([self.template_path,
+                                            'properties.sql']), cid=scid)
+            status, res = self.conn.execute_dict(SQL)
+            if not status:
+                return internal_server_error(errormsg=res)
+            old_data = res['rows'][0]
+            SQL = render_template("/".join([self.template_path, 'update.sql']),
+                                  data=data, o_data=old_data, conn=self.conn)
+        else:
+            SQL = '-- No change!'
+        return SQL
+
+    @check_precondition
+    def sql(self, gid, sid, did, scid):
+        """
+        This function will genrate sql for sql panel
+        """
+        SQL = render_template("/".join([self.template_path,
+                                        'properties.sql']), cid=scid)
+        status, res = self.conn.execute_dict(SQL)
+        if not status:
+            return internal_server_error(errormsg=res)
+        old_data = res['rows'][0]
+
+        # We need to parse & convert ACL coming from database to json format
+        SQL = render_template("/".join([self.template_path, 'acl.sql']),
+                              cid=scid)
+        status, acl = self.conn.execute_dict(SQL)
+        if not status:
+            return internal_server_error(errormsg=acl)
+
+        # We will set get privileges from acl sql so we don't need
+        # it from properties sql
+        old_data['nspacl'] = []
+
+        for row in acl['rows']:
+            priv = parse_priv_from_db(row)
+            if row['deftype'] in old_data:
+                old_data[row['deftype']].append(priv)
+            else:
+                old_data[row['deftype']] = [priv]
+
+        old_data['nspacl'] = parse_priv_to_db(old_data['nspacl'], 'SCHEMA')
+
+        SQL = render_template("/".join([self.template_path, 'create.sql']),
+                              data=old_data, conn=self.conn)
+
+        sql_header = """
+-- SCHEMA: {0};
+
+-- DROP SCHEMA {0};
+
+""".format(old_data['name'])
+
+        SQL = sql_header + SQL
+
+        return ajax_response(response=SQL)
+
+
+CatalogView.register_node_view(catalog_blueprint)
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/catalog.png b/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/catalog.png
new file mode 100644
index 0000000000000000000000000000000000000000..7c0ef24ff5843867fb64d97cc419a7150da5f441
GIT binary patch
literal 387
zcmeAS@N?(olHy`uVBq!ia0vp^0wB!63?wyl`GbL!eSlAhE0A74<wm*Z-rc?bcXt2Z
z(fNN{>wh5F-1vWE-M=SKm;e3mx31#fzyGsVm;76i_it&|zr|_)79{<fpYU%^)W1Ea
z-**6wU@Qsp3ubV5b|VeMN%D4gVHZp6cn#!m7I;J!18EO1b~~AE2V~@Vx;TbNT#oJM
z6lzf5aDBKvBPsIQ-}AFx7)0?b-q)Ywa#bQhs>jfG@u3-kbFB3rR7tE)c>e0@4eiyB
zLKAaZn>`A?dUi-nuND6*>}cWk(81HwR&}e=a#7p0XRqFhtDUf>`Dx)5>7(|iZO+%n
zJ{F&HpV>2Gt>-78&8j7?5hW>!C8<`)MX5lF!N|bSK-bVn*T68u$iT|P*viC2+rZSy
vz`$arsvL@j-29Zxv`UBu152<5kZLOfGl+&$(?iz)H86O(`njxgN@xNA6A6=n

literal 0
HcmV?d00001

diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/coll-catalog.png b/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/coll-catalog.png
new file mode 100644
index 0000000000000000000000000000000000000000..caa6d3d40d55d990351465cebacbffde95eeb63d
GIT binary patch
literal 371
zcmeAS@N?(olHy`uVBq!ia0vp^0wB!63?wyl`GbL!aez;VE0A74<wm*Z-rc?bcXa;W
z+Wa2~`Z7*ztozp=cVk_}zm*05{{Hv-_kY&XtbYrV{>_W~_vF9f0-!d=k|4ie28U-i
z(m<RfZ+92A#Izl?Kn`btM`SUO_5fqIli7AaMwX|GV~E7%(0*>d1_d7H%+Qbz<^L~7
z1qs|Sn)G$;X%0t5r5;8<d)7HqC4RLAZVltTbH)AL+2c$4Ry|`jW?g;0E8wGSp#GjM
zKl*~bl47;uXP%g4prU_rx@_B?sUH;EYHn>ckg4n7vtRmMKl%{UE#@beKLBl2Epd$~
zNl7e8wMs5Z1yT$~28IT@hDN#uh9O1<Rwl+)CMMbjrd9?97Bf}lP&DM`r(~v8LNpjy
df;E6tTN#)^G@P0qx(29$!PC{xWt~$(697gUhCKiP

literal 0
HcmV?d00001

diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/coll-schema.png b/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/coll-schema.png
new file mode 100644
index 0000000000000000000000000000000000000000..9733882b720b39bfed266843f84e1278c9bc588f
GIT binary patch
literal 374
zcmeAS@N?(olHy`uVBq!ia0vp^0wB!73?$#)eFPHF4e$wZ1=2UBOxf${`M<aKe@Dmv
z=H~zZ|DVXn_+MLlBQEZLS=s;m{Qp31Lc;%;7|~9dUZ4iXk|4ie28U-i(m<RfZ+92A
z#Izl?Kn`btM`SUO_5fqIli7AaMzN=hV+hA}-M&E41_KV)g$I`$ys*%Hxx8CMi>pGH
zU{3;zvcy3SwTZqD+l$Y)vNKF*j=J$Hf58;3LkbJ^d(5uZnwoKWUzc38`RSUQj73r|
zZ23m=S+P$%Q$DHn*Svh{6E-*f_92al^NVJ`+r2V#$Df7&rS+Sxi6&jF{agpMUbVzE
zq9i4;B-JXpC>2OC7#SEE=o%X78W@Hc8CaPZTbY<@8<<)d7|eU8w+cl=ZhlH;S|vn-
gfhAZ2P_>Dbff+=@sp+9>fEpM)UHx3vIVCg!0CBE_(*OVf

literal 0
HcmV?d00001

diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/schema.png b/web/pgadmin/browser/server_groups/servers/databases/schemas/static/img/schema.png
new file mode 100644
index 0000000000000000000000000000000000000000..4dacf1856fe53575aa1ee93bc146fd2a37b32650
GIT binary patch
literal 376
zcmeAS@N?(olHy`uVBq!ia0vp^0wB!63?wyl`GbL!S%6Q7E0Df1Wy)Sp&;Px>|GT>W
zcXa%3Y55NX4GsTmYW|m(|1U27pPTzXGxL9H>i>j<|8a5uBO`y?dmIGnWGo5t3ubV5
zb|VeMN%D4gVHZp6cn#!m7I;J!18EO1b~~AE2V~@Ux;TbNT#ohc7HUx7XpYSMaq9p7
zn=I!qKe8xwzM-%wp&^sIt=Rgo#f8b@b_dIRY8v-$&wj8VV&(##$L}IS_t<hSD(!Ii
z&%trAL!!6ig>L57C59^J7gnB{q8L4G;;Lh>^1eErKX0`5@AbJqSl#`ZmagB%I2CBG
zYKdz^NlIc#s#S7PDv)9@GB7mIH8j#SFbpv=ure{WGBMRQFtsu;nD<U^6^e%3{FKbJ
jN{9vnORxr@Y7;91Gl+&$(?iz)H86O(`njxgN@xNAXB&$`

literal 0
HcmV?d00001

diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/js/catalogs.js b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/js/catalogs.js
new file mode 100644
index 0000000..68e5327
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/js/catalogs.js
@@ -0,0 +1,116 @@
+define(
+        ['jquery', 'underscore', 'underscore.string', 'pgadmin', 'pgadmin.browser', 'alertify', 'pgadmin.browser.collection'],
+function($, _, S, pgAdmin, pgBrowser, alertify) {
+
+   var SecurityModel = Backform.SecurityModel = pgAdmin.Browser.Node.Model.extend({
+    defaults: {
+      provider: null,
+      security_label: null
+    },
+    schema: [{
+      id: 'provider', label: '{{ _('Provider') }}',
+      type: 'text', disabled: false
+    },{
+      id: 'security_label', label: '{{ _('Security Label') }}',
+      type: 'text', disabled: false
+    }],
+    validate: function() {
+      var err = {},
+          errmsg = null,
+          data = this.toJSON();
+
+      if (_.isUndefined(this.get('security_label')) ||
+        _.isNull(this.get('security_label')) ||
+        String(this.get('security_label')).replace(/^\s+|\s+$/g, '') == '') {
+            errmsg = '{{ _('Please specify the value for all the security providers.')}}';
+            this.errorModel.set('security_label', errmsg);
+            return errmsg;
+          } else {
+            this.errorModel.unset('security_label');
+          }
+      return null;
+    }
+  });
+
+  if (!pgBrowser.Nodes['coll-catalog']) {
+    var databases = pgAdmin.Browser.Nodes['coll-catalog'] =
+      pgAdmin.Browser.Collection.extend({
+        node: 'catalog',
+        label: '{{ _('Catalogs') }}',
+        type: 'coll-catalog',
+        columns: ['name', 'oid', 'description']
+      });
+  };
+
+  if (!pgBrowser.Nodes['catalog']) {
+    pgAdmin.Browser.Nodes['catalog'] = pgAdmin.Browser.Node.extend({
+      parent_type: 'database',
+      type: 'catalog',
+      label: '{{ _('Catalog') }}',
+      hasSQL:  true,
+      Init: function() {
+        /* Avoid mulitple registration of menus */
+        if (this.initialized)
+            return;
+
+        this.initialized = true;
+
+      },
+      model: pgAdmin.Browser.Node.Model.extend({
+        defaults: {
+          name: undefined,
+          namespaceowner: undefined,
+          nspacl: undefined,
+          description: undefined,
+          acltbl: undefined,
+          aclseq: undefined,
+          aclfunc: undefined,
+          acltype: undefined,
+          slony: undefined,
+          securitylabel: []
+        },
+        schema: [{
+          id: 'name', label: '{{ _('Name') }}', cell: 'string',
+          type: 'text', disabled: true
+        },{
+          id: 'oid', label:'{{ _('Oid') }}', cell: 'string',
+          type: 'text', disabled: true
+        },{
+          id: 'namespaceowner', label:'{{ _('Owner') }}', cell: 'string',
+          type: 'text', disabled: true
+        },{
+          id: 'nspacl', label:'{{ _('ACL') }}', cell: 'string',
+          type: 'text', mode: ['properties']
+        },{
+          id: 'acltbl', label:'{{ _('Default table ACL') }}', cell: 'string',
+          type: 'text', mode: ['properties']
+        },{
+          id: 'aclseq', label:'{{ _('Default sequence ACL') }}', cell: 'string',
+          type: 'text', mode: ['properties']
+        },{
+          id: 'aclfunc', label:'{{ _('Default function ACL') }}', cell: 'string',
+          type: 'text', mode: ['properties']
+        },{
+          id: 'acltype', label:'{{ _('Default type ACL') }}', cell: 'string',
+          type: 'text', mode: ['properties']
+       },{
+          id: 'description', label:'{{ _('Comment') }}', cell: 'string',
+          type: 'multiline'
+       },{
+          id: 'seclabels', label: '{{ _('Security Labels') }}',
+          model: SecurityModel, editable: false, type: 'collection',
+          group: '{{ _('Security') }}', mode: ['edit', 'create'],
+          min_version: 90100, canAdd: true,
+          canEdit: false, canDelete: true, control: 'unique-col-collection'
+         }
+        ],
+        validate: function() {
+          return null;
+        }
+      })
+  });
+
+  }
+
+  return pgBrowser.Nodes['coll-catalog'];
+});
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/acl.sql
new file mode 100644
index 0000000..6bf9c86
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/acl.sql
@@ -0,0 +1,62 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/create.sql
new file mode 100644
index 0000000..92480ea
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/create.sql
@@ -0,0 +1,18 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}
+{% if data.namespaceowner %}
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/properties.sql
new file mode 100644
index 0000000..c2fa29d
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/properties.sql
@@ -0,0 +1,29 @@
+SELECT nsp.nspname AS name, nsp.oid AS oid, pg_get_userbyid(nsp.nspowner) AS namespaceowner, nsp.nspacl AS nspacl,
+ des.description,
+ CASE WHEN dacl.defaclobjtype='r' THEN dacl.defaclacl END AS acltbl,
+ CASE WHEN dacl.defaclobjtype='S' THEN dacl.defaclacl END AS aclseq,
+ CASE WHEN dacl.defaclobjtype='f' THEN dacl.defaclacl END AS aclfunc,
+ (SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+{% if cid %}
+AND
+ nsp.oid={{cid}}::int
+{% endif %}
+ORDER BY nsp.nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/update.sql
new file mode 100644
index 0000000..7ac1193
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.1_plus/update.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% if data %}
+{# ==== To update catalog comments ==== #}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(o_data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{# ==== To update catalog securitylabel ==== #}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', o_data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/acl.sql
new file mode 100644
index 0000000..6bf9c86
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/acl.sql
@@ -0,0 +1,62 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/create.sql
new file mode 100644
index 0000000..92480ea
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/create.sql
@@ -0,0 +1,18 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}
+{% if data.namespaceowner %}
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/properties.sql
new file mode 100644
index 0000000..5e2cff9
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/properties.sql
@@ -0,0 +1,30 @@
+SELECT nsp.nspname AS name, nsp.oid AS oid, pg_get_userbyid(nsp.nspowner) AS namespaceowner, nsp.nspacl AS nspacl,
+ des.description,
+ CASE WHEN dacl.defaclobjtype='r' THEN dacl.defaclacl END AS acltbl,
+ CASE WHEN dacl.defaclobjtype='S' THEN dacl.defaclacl END AS aclseq,
+ CASE WHEN dacl.defaclobjtype='f' THEN dacl.defaclacl END AS aclfunc,
+ CASE WHEN dacl.defaclobjtype='T' THEN dacl.defaclacl END AS acltype,
+ (SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+{% if cid %}
+AND
+ nsp.oid={{cid}}::int
+{% endif %}
+ORDER BY nsp.nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/update.sql
new file mode 100644
index 0000000..7ac1193
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/9.2_plus/update.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% if data %}
+{# ==== To update catalog comments ==== #}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(o_data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{# ==== To update catalog securitylabel ==== #}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', o_data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/acl.sql
new file mode 100644
index 0000000..2b3618b
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/acl.sql
@@ -0,0 +1,66 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+  (nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+  (nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/create.sql
new file mode 100644
index 0000000..92480ea
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/create.sql
@@ -0,0 +1,18 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}
+{% if data.namespaceowner %}
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/properties.sql
new file mode 100644
index 0000000..e1d8e14
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/properties.sql
@@ -0,0 +1,33 @@
+SELECT nsp.nspname AS name, nsp.oid AS oid, pg_get_userbyid(nsp.nspowner) AS namespaceowner, nsp.nspacl AS nspacl,
+ des.description,
+ CASE WHEN dacl.defaclobjtype='r' THEN dacl.defaclacl END AS acltbl,
+ CASE WHEN dacl.defaclobjtype='S' THEN dacl.defaclacl END AS aclseq,
+ CASE WHEN dacl.defaclobjtype='f' THEN dacl.defaclacl END AS aclfunc,
+ (SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM pg_namespace nsp 
+LEFT OUTER JOIN 
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+	(nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.nspparent = 0
+{% if cid %}
+AND
+ nsp.oid={{cid}}::int
+{% endif %}
+ORDER BY nsp.nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/update.sql
new file mode 100644
index 0000000..7ac1193
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.1_plus/update.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% if data %}
+{# ==== To update catalog comments ==== #}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(o_data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{# ==== To update catalog securitylabel ==== #}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', o_data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/acl.sql
new file mode 100644
index 0000000..2b3618b
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/acl.sql
@@ -0,0 +1,66 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+  (nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+  (nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/create.sql
new file mode 100644
index 0000000..92480ea
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/create.sql
@@ -0,0 +1,18 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}
+{% if data.namespaceowner %}
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/properties.sql
new file mode 100644
index 0000000..24db4c5
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/properties.sql
@@ -0,0 +1,34 @@
+SELECT nsp.nspname AS name, nsp.oid AS oid, pg_get_userbyid(nsp.nspowner) AS namespaceowner, nsp.nspacl AS nspacl,
+ des.description,
+ CASE WHEN dacl.defaclobjtype='r' THEN dacl.defaclacl END AS acltbl,
+ CASE WHEN dacl.defaclobjtype='S' THEN dacl.defaclacl END AS aclseq,
+ CASE WHEN dacl.defaclobjtype='f' THEN dacl.defaclacl END AS aclfunc,
+ CASE WHEN dacl.defaclobjtype='T' THEN dacl.defaclacl END AS acltype,
+ (SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM pg_namespace nsp 
+LEFT OUTER JOIN 
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+	(nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.nspparent = 0
+{% if cid %}
+AND
+ nsp.oid={{cid}}::int
+{% endif %}
+ORDER BY nsp.nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/update.sql
new file mode 100644
index 0000000..7ac1193
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_9.2_plus/update.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% if data %}
+{# ==== To update catalog comments ==== #}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(o_data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{# ==== To update catalog securitylabel ==== #}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', o_data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', o_data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/acl.sql
new file mode 100644
index 0000000..2b3618b
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/acl.sql
@@ -0,0 +1,66 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+  (nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+  (nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/create.sql
new file mode 100644
index 0000000..92480ea
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/create.sql
@@ -0,0 +1,18 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}
+{% if data.namespaceowner %}
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/properties.sql
new file mode 100644
index 0000000..1456c76
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/properties.sql
@@ -0,0 +1,32 @@
+SELECT nsp.nspname AS name, nsp.oid AS oid, pg_get_userbyid(nsp.nspowner) AS namespaceowner, nsp.nspacl AS nspacl,
+ des.description,
+ CASE WHEN dacl.defaclobjtype='r' THEN dacl.defaclacl END AS acltbl,
+ CASE WHEN dacl.defaclobjtype='S' THEN dacl.defaclacl END AS aclseq,
+ CASE WHEN dacl.defaclobjtype='f' THEN dacl.defaclacl END AS aclfunc
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+OR
+	(nspname = 'dbo' OR nspname = 'sys')
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.nspparent = 0
+{% if cid %}
+AND
+ nsp.oid={{cid}}::int
+{% endif %}
+ORDER BY nsp.nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/update.sql
new file mode 100644
index 0000000..d7224c3
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/edb_pre_9.1/update.sql
@@ -0,0 +1,9 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% if data %}
+{# ==== To update catalog comments ==== #}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(o_data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/acl.sql
new file mode 100644
index 0000000..6bf9c86
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/acl.sql
@@ -0,0 +1,62 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+AND
+ nsp.oid={{cid}}::int
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/create.sql
new file mode 100644
index 0000000..92480ea
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/create.sql
@@ -0,0 +1,18 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}
+{% if data.namespaceowner %}
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/properties.sql
new file mode 100644
index 0000000..8240e8a
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/properties.sql
@@ -0,0 +1,28 @@
+SELECT nsp.nspname AS name, nsp.oid AS oid, pg_get_userbyid(nsp.nspowner) AS namespaceowner, nsp.nspacl AS nspacl,
+ des.description,
+ CASE WHEN dacl.defaclobjtype='r' THEN dacl.defaclacl END AS acltbl,
+ CASE WHEN dacl.defaclobjtype='S' THEN dacl.defaclacl END AS aclseq,
+ CASE WHEN dacl.defaclobjtype='f' THEN dacl.defaclacl END AS aclfunc
+FROM pg_namespace nsp
+LEFT OUTER JOIN
+ pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE (
+(nspname = 'pg_catalog' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'pgagent' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname = 'information_schema' AND EXISTS
+                               (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1))
+OR (nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)
+AND
+ nspname NOT LIKE E'pg\\temp\\%'
+AND
+ nspname NOT LIKE E'pg\\toast_temp\\%'
+{% if cid %}
+AND
+ nsp.oid={{cid}}::int
+{% endif %}
+ORDER BY nsp.nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/update.sql
new file mode 100644
index 0000000..d7224c3
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/catalogs/sql/pre_9.1/update.sql
@@ -0,0 +1,9 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% if data %}
+{# ==== To update catalog comments ==== #}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(o_data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/js/schemas.js b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/js/schemas.js
new file mode 100644
index 0000000..43ae049
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/js/schemas.js
@@ -0,0 +1,180 @@
+define(
+        ['jquery', 'underscore', 'underscore.string', 'pgadmin', 'pgadmin.browser',
+        'alertify', 'pgadmin.browser.collection','pgadmin.browser.server.privilege'
+        ],
+function($, _, S, pgAdmin, pgBrowser, alertify) {
+
+   var SecurityModel = Backform.SecurityModel = pgAdmin.Browser.Node.Model.extend({
+    defaults: {
+      provider: null,
+      security_label: null
+    },
+    schema: [{
+      id: 'provider', label: '{{ _('Provider') }}',
+      type: 'text', disabled: false
+    },{
+      id: 'security_label', label: '{{ _('Security Label') }}',
+      type: 'text', disabled: false
+    }],
+    validate: function() {
+      var err = {},
+          errmsg = null,
+          data = this.toJSON();
+
+      if (_.isUndefined(this.get('security_label')) ||
+        _.isNull(this.get('security_label')) ||
+        String(this.get('security_label')).replace(/^\s+|\s+$/g, '') == '') {
+            errmsg = '{{ _('Please specify the value for all the security providers.')}}';
+            this.errorModel.set('security_label', errmsg);
+            return errmsg;
+          } else {
+            this.errorModel.unset('security_label');
+          }
+      return null;
+    }
+  });
+
+  if (!pgBrowser.Nodes['coll-schema']) {
+    var databases = pgAdmin.Browser.Nodes['coll-schema'] =
+      pgAdmin.Browser.Collection.extend({
+        node: 'schema',
+        label: '{{ _('Schemas') }}',
+        type: 'coll-schema',
+        columns: ['name', 'oid', 'description']
+      });
+  };
+
+  if (!pgBrowser.Nodes['schema']) {
+    pgAdmin.Browser.Nodes['schema'] = pgAdmin.Browser.Node.extend({
+      parent_type: 'database',
+      type: 'schema',
+      label: '{{ _('Schema') }}',
+      hasSQL:  true,
+      canDrop: true,
+      canDropCascade: true,
+      Init: function() {
+        /* Avoid mulitple registration of menus */
+        if (this.initialized)
+            return;
+
+        this.initialized = true;
+
+        pgBrowser.add_menus([{
+          name: 'create_schema_on_coll', node: 'coll-schema', module: this,
+          applies: ['object', 'context'], callback: 'show_obj_properties',
+          category: 'create', priority: 4, label: '{{ _('Schema...') }}',
+          icon: 'wcTabIcon icon-schema', data: {action: 'create'}
+        },{
+          name: 'create_schema', node: 'schema', module: this,
+          applies: ['object', 'context'], callback: 'show_obj_properties',
+          category: 'create', priority: 4, label: '{{ _('Schema...') }}',
+          icon: 'wcTabIcon icon-schema', data: {action: 'create'}
+        }
+        ]);
+      },
+      model: pgAdmin.Browser.Node.Model.extend({
+        defaults: {
+          name: undefined,
+          namespaceowner: undefined,
+          description: undefined,
+          is_system_obj: undefined,
+        },
+        schema: [{
+          id: 'name', label: '{{ _('Name') }}', cell: 'string',
+          type: 'text'
+        },{
+          id: 'oid', label:'{{ _('Oid') }}', cell: 'string',
+          type: 'text', disabled: true, mode: ['edit', 'properties']
+        },{
+          id: 'namespaceowner', label:'{{ _('Owner') }}', cell: 'string',
+          type: 'text', control: 'node-list-by-name', node: 'role'
+        },{
+          id: 'description', label:'{{ _('Comment') }}', cell: 'string',
+          type: 'multiline'
+        },{
+          id: 'nspacl', label: '{{ _('Privileges') }}',
+          model: pgAdmin.Browser.Node.PrivilegeRoleModel.extend(
+          {privileges: ['C', 'U']}), uniqueCol : ['grantee', 'grantor'],
+          editable: false, type: 'collection', group: '{{ _('Security') }}',
+          mode: ['properties', 'edit', 'create'],
+          canAdd: true, canDelete: true, control: 'unique-col-collection',
+        },{
+          id: 'seclabels', label: '{{ _('Security Labels') }}',
+          model: SecurityModel, editable: false, type: 'collection',
+          group: '{{ _('Security') }}', mode: ['edit', 'create'],
+          min_version: 90100, canAdd: true,
+          canEdit: false, canDelete: true, control: 'unique-col-collection'
+        },{
+          type: 'nested', control: 'tab', group: '{{ _('Default Privileges') }}',
+          mode: ['edit'],
+          schema:[{
+              id: 'deftblacl', model: pgAdmin.Browser.Node.PrivilegeRoleModel.extend(
+              {privileges: ['a', 'r', 'w', 'd', 'D', 'x', 't']}), label: '{{ _('Default Privileges: Tables') }}',
+              editable: false, type: 'collection', group: '{{ _('Tables') }}',
+              mode: ['edit', 'create'], control: 'unique-col-collection',
+              canAdd: true, canDelete: true, uniqueCol : ['grantee', 'grantor']
+            },{
+              id: 'defseqacl', model: pgAdmin.Browser.Node.PrivilegeRoleModel.extend(
+              {privileges: ['r', 'w', 'U']}), label: '{{ _('Default Privileges: Sequences') }}',
+              editable: false, type: 'collection', group: '{{ _('Sequences') }}',
+              mode: ['edit', 'create'], control: 'unique-col-collection',
+              canAdd: true, canDelete: true, uniqueCol : ['grantee', 'grantor']
+            },{
+              id: 'deffuncacl', model: pgAdmin.Browser.Node.PrivilegeRoleModel.extend(
+              {privileges: ['X']}), label: '{{ _('Default Privileges: Functions') }}',
+              editable: false, type: 'collection', group: '{{ _('Functions') }}',
+              mode: ['edit', 'create'], control: 'unique-col-collection',
+              canAdd: true, canDelete: true, uniqueCol : ['grantee', 'grantor']
+            },{
+              id: 'deftypeacl', model: pgAdmin.Browser.Node.PrivilegeRoleModel.extend(
+              {privileges: ['U']}),  label: '{{ _('Default Privileges: Types') }}',
+              editable: false, type: 'collection', group: '{{ _('Types') }}',
+              mode: ['edit', 'create'], control: 'unique-col-collection',
+              canAdd: true, canDelete: true, uniqueCol : ['grantee', 'grantor'],
+              min_version: 90200
+            }]
+         }
+        ],
+        validate: function() {
+          var err = {},
+              errmsg = null,
+              data = this.toJSON();
+
+          if (_.isUndefined(this.get('name')) ||
+            _.isNull(this.get('name')) ||
+            String(this.get('name')).replace(/^\s+|\s+$/g, '') == '') {
+                errmsg = '{{ _('Name can not be empty.')}}';
+                this.errorModel.set('name', errmsg);
+                return errmsg;
+              } else {
+                this.errorModel.unset('name');
+              }
+          return null;
+        }
+      }),
+      canChildDrop: function(itemData, item) {
+        var t = pgBrowser.tree, i = item, d = itemData;
+        // To iterate over tree to check parent node
+        while (i) {
+          // If it is schema then allow user to create collation
+          if (_.indexOf(['schema'], d._type) > -1)
+            return true;
+
+            //Check if we are not child of catalog
+            prev_i = t.hasParent(i) ? t.parent(i) : null;
+            prev_d = prev_i ? t.itemData(prev_i) : null;
+            if( prev_d._type == 'catalog') {
+              return false;
+            }
+          i = t.hasParent(i) ? t.parent(i) : null;
+          d = i ? t.itemData(i) : null;
+        }
+        // by default we do not want to allow create menu
+        return true;
+      }
+  });
+
+  }
+
+  return pgBrowser.Nodes['coll-schema'];
+});
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/acl.sql
new file mode 100644
index 0000000..5121270
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/acl.sql
@@ -0,0 +1,54 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/alter.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/alter.sql
new file mode 100644
index 0000000..a5c2bd5
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/alter.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{###  To alter description ###}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Security Labels on schema ###}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% for r in data.seclabels %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+
+{% endif %}
+{###  ACL on schema ###}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+
+{% endif %}
+{### End of main if ###}
+{% endif %}
+{# ======== Below SQL will fetch id for given dataspace ======== #}
+{% if schema %}
+SELECT nsp.oid FROM pg_namespace nsp WHERE nsp.nspname = {{schema|qtLiteral}};
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/create.sql
new file mode 100644
index 0000000..96bc4e6
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/create.sql
@@ -0,0 +1,6 @@
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}{% if data.namespaceowner %}
+
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }}{% endif %};
+{% endif %}
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/defacl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/defacl.sql
new file mode 100644
index 0000000..bbad25d
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/defacl.sql
@@ -0,0 +1,39 @@
+SELECT
+	CASE (a.deftype)
+	WHEN 'r' THEN 'deftblacl'
+	WHEN 'S' THEN 'defseqacl'
+	WHEN 'f' THEN 'deffuncacl'
+	WHEN 'T' THEN 'deftypeacl'
+	END AS deftype,
+	COALESCE(gt.rolname, 'public') grantee, g.rolname grantor, array_agg(a.privilege_type) as privileges, array_agg(a.is_grantable) as grantable
+FROM
+	(SELECT
+		(acl).grantee as grantee, (acl).grantor AS grantor, (acl).is_grantable AS is_grantable,
+		CASE (acl).privilege_type
+		WHEN 'CONNECT' THEN 'c'
+		WHEN 'CREATE' THEN 'C'
+		WHEN 'DELETE' THEN 'd'
+		WHEN 'EXECUTE' THEN 'X'
+		WHEN 'INSERT' THEN 'a'
+		WHEN 'REFERENCES' THEN 'x'
+		WHEN 'SELECT' THEN 'r'
+		WHEN 'TEMPORARY' THEN 'T'
+		WHEN 'TRIGGER' THEN 't'
+		WHEN 'TRUNCATE' THEN 'D'
+		WHEN 'UPDATE' THEN 'w'
+		WHEN 'USAGE' THEN 'U'
+		ELSE 'UNKNOWN'
+		END AS privilege_type,
+		defaclobjtype as deftype
+	FROM
+		(SELECT defaclobjtype, aclexplode(defaclacl) as acl 
+			FROM
+				pg_namespace nsp
+				LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+			WHERE
+				nsp.oid={{scid}}::int
+        ) d) a
+	LEFT JOIN pg_catalog.pg_roles g ON (a.grantor = g.oid)
+	LEFT JOIN pg_catalog.pg_roles gt ON (a.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname, a.deftype
+ORDER BY a.deftype
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/delete.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/delete.sql
new file mode 100644
index 0000000..7686040
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/delete.sql
@@ -0,0 +1,8 @@
+{% if scid %}
+SELECT nsp.nspname as name, nsp.oid
+FROM pg_namespace nsp
+WHERE nsp.oid = {{scid}};
+{% endif %}
+{% if name %}
+DROP SCHEMA {{ conn|qtIdent(name) }} {% if cascade %}CASCADE{%endif%};
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/properties.sql
new file mode 100644
index 0000000..8942982
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/properties.sql
@@ -0,0 +1,30 @@
+SELECT
+	CASE
+	WHEN (nspname LIKE E'pg\\\\_temp\\\\_%') THEN 1
+	WHEN (nspname LIKE E'pg\\\\_%') THEN 0
+	ELSE 3 END
+	AS nsptyp,
+	nsp.nspname as name, nsp.oid,
+	pg_get_userbyid(nspowner) AS namespaceowner, description,
+	has_schema_privilege(nsp.oid, 'CREATE') as cancreate,
+	CASE WHEN nspname LIKE E'pg\\_%' THEN true ELSE false END as is_sys_object,
+    (SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM
+	pg_namespace nsp
+	LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+WHERE
+	NOT ((nspname = 'pg_catalog' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'pgagent' AND EXISTS
+	(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'information_schema' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+	)AND
+	{% if scid %}
+	nsp.oid={{scid}}::int AND
+	{% endif %}
+	nspname NOT LIKE E'pg\\temp\\%' AND
+	nspname NOT LIKE E'pg\\toast_temp\\%'
+ORDER BY 1, nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/update.sql
new file mode 100644
index 0000000..fe3fcad
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.1_plus/update.sql
@@ -0,0 +1,125 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{### To update SCHEMA name ###}
+{% if data.name and data.name != o_data.name %}
+ALTER SCHEMA {{ conn|qtIdent(o_data.name) }}
+  RENAME TO {{ conn|qtIdent(data.name) }};
+
+{% endif %}
+{### To update SCHEMA owner ###}
+{% if data.namespaceowner and data.namespaceowner != o_data.namespaceowner %}
+ALTER SCHEMA {{ conn|qtIdent(data.name) }}
+  OWNER TO {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{### To update SCHEMA comments ###}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Change the security labels ###}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### Change the privileges ###}
+{% if data.nspacl %}
+{% if 'deleted' in data.nspacl %}
+{% for priv in data.nspacl.deleted %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.nspacl %}
+{% for priv in data.nspacl.changed %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.nspacl %}
+{% for priv in data.nspacl.added %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for tables ###}
+{% if data.deftblacl %}
+{% if 'deleted' in data.deftblacl %}
+{% for priv in data.deftblacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deftblacl %}
+{% for priv in data.deftblacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deftblacl %}
+{% for priv in data.deftblacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for sequences ###}
+{% if data.defseqacl %}
+{% if 'deleted' in data.defseqacl %}
+{% for priv in data.defseqacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.defseqacl %}
+{% for priv in data.defseqacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.defseqacl %}
+{% for priv in data.defseqacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for functions ###}
+{% if data.deffuncacl %}
+{% if 'deleted' in data.deffuncacl %}
+{% for priv in data.deffuncacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deffuncacl %}
+{% for priv in data.deffuncacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deffuncacl %}
+{% for priv in data.deffuncacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{###  End main if data ###}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/acl.sql
new file mode 100644
index 0000000..5121270
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/acl.sql
@@ -0,0 +1,54 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/alter.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/alter.sql
new file mode 100644
index 0000000..a5c2bd5
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/alter.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{###  To alter description ###}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Security Labels on schema ###}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% for r in data.seclabels %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+
+{% endif %}
+{###  ACL on schema ###}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+
+{% endif %}
+{### End of main if ###}
+{% endif %}
+{# ======== Below SQL will fetch id for given dataspace ======== #}
+{% if schema %}
+SELECT nsp.oid FROM pg_namespace nsp WHERE nsp.nspname = {{schema|qtLiteral}};
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/create.sql
new file mode 100644
index 0000000..96bc4e6
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/create.sql
@@ -0,0 +1,6 @@
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}{% if data.namespaceowner %}
+
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }}{% endif %};
+{% endif %}
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/defacl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/defacl.sql
new file mode 100644
index 0000000..4167168
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/defacl.sql
@@ -0,0 +1,39 @@
+SELECT
+	CASE (a.deftype)
+	WHEN 'r' THEN 'deftblacl'
+	WHEN 'S' THEN 'defseqacl'
+	WHEN 'f' THEN 'deffuncacl'
+	WHEN 'T' THEN 'deftypeacl'
+	END AS deftype,
+	COALESCE(gt.rolname, 'public') grantee, g.rolname grantor, array_agg(a.privilege_type) as privileges, array_agg(a.is_grantable) as grantable
+FROM
+	(SELECT
+		(acl).grantee as grantee, (acl).grantor AS grantor, (acl).is_grantable AS is_grantable,
+		CASE (acl).privilege_type
+		WHEN 'CONNECT' THEN 'c'
+		WHEN 'CREATE' THEN 'C'
+		WHEN 'DELETE' THEN 'd'
+		WHEN 'EXECUTE' THEN 'X'
+		WHEN 'INSERT' THEN 'a'
+		WHEN 'REFERENCES' THEN 'x'
+		WHEN 'SELECT' THEN 'r'
+		WHEN 'TEMPORARY' THEN 'T'
+		WHEN 'TRIGGER' THEN 't'
+		WHEN 'TRUNCATE' THEN 'D'
+		WHEN 'UPDATE' THEN 'w'
+		WHEN 'USAGE' THEN 'U'
+		ELSE 'UNKNOWN'
+		END AS privilege_type,
+		defaclobjtype as deftype
+	FROM
+		(SELECT defaclobjtype, aclexplode(defaclacl) as acl
+			FROM
+				pg_namespace nsp
+				LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+			WHERE
+				nsp.oid={{scid}}::int
+        ) d) a
+	LEFT JOIN pg_catalog.pg_roles g ON (a.grantor = g.oid)
+	LEFT JOIN pg_catalog.pg_roles gt ON (a.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname, a.deftype
+ORDER BY a.deftype
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/delete.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/delete.sql
new file mode 100644
index 0000000..7686040
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/delete.sql
@@ -0,0 +1,8 @@
+{% if scid %}
+SELECT nsp.nspname as name, nsp.oid
+FROM pg_namespace nsp
+WHERE nsp.oid = {{scid}};
+{% endif %}
+{% if name %}
+DROP SCHEMA {{ conn|qtIdent(name) }} {% if cascade %}CASCADE{%endif%};
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/properties.sql
new file mode 100644
index 0000000..8942982
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/properties.sql
@@ -0,0 +1,30 @@
+SELECT
+	CASE
+	WHEN (nspname LIKE E'pg\\\\_temp\\\\_%') THEN 1
+	WHEN (nspname LIKE E'pg\\\\_%') THEN 0
+	ELSE 3 END
+	AS nsptyp,
+	nsp.nspname as name, nsp.oid,
+	pg_get_userbyid(nspowner) AS namespaceowner, description,
+	has_schema_privilege(nsp.oid, 'CREATE') as cancreate,
+	CASE WHEN nspname LIKE E'pg\\_%' THEN true ELSE false END as is_sys_object,
+    (SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM
+	pg_namespace nsp
+	LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+WHERE
+	NOT ((nspname = 'pg_catalog' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'pgagent' AND EXISTS
+	(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'information_schema' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+	)AND
+	{% if scid %}
+	nsp.oid={{scid}}::int AND
+	{% endif %}
+	nspname NOT LIKE E'pg\\temp\\%' AND
+	nspname NOT LIKE E'pg\\toast_temp\\%'
+ORDER BY 1, nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/update.sql
new file mode 100644
index 0000000..d8bc687
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/9.2_plus/update.sql
@@ -0,0 +1,145 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{### To update SCHEMA name ###}
+{% if data.name and data.name != o_data.name %}
+ALTER SCHEMA {{ conn|qtIdent(o_data.name) }}
+  RENAME TO {{ conn|qtIdent(data.name) }};
+
+{% endif %}
+{### To update SCHEMA owner ###}
+{% if data.namespaceowner and data.namespaceowner != o_data.namespaceowner %}
+ALTER SCHEMA {{ conn|qtIdent(data.name) }}
+  OWNER TO {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{### To update SCHEMA comments ###}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Change the security labels ###}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### Change the privileges ###}
+{% if data.nspacl %}
+{% if 'deleted' in data.nspacl %}
+{% for priv in data.nspacl.deleted %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.nspacl %}
+{% for priv in data.nspacl.changed %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.nspacl %}
+{% for priv in data.nspacl.added %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for tables ###}
+{% if data.deftblacl %}
+{% if 'deleted' in data.deftblacl %}
+{% for priv in data.deftblacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deftblacl %}
+{% for priv in data.deftblacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deftblacl %}
+{% for priv in data.deftblacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for sequences ###}
+{% if data.defseqacl %}
+{% if 'deleted' in data.defseqacl %}
+{% for priv in data.defseqacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.defseqacl %}
+{% for priv in data.defseqacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.defseqacl %}
+{% for priv in data.defseqacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for functions ###}
+{% if data.deffuncacl %}
+{% if 'deleted' in data.deffuncacl %}
+{% for priv in data.deffuncacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deffuncacl %}
+{% for priv in data.deffuncacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deffuncacl %}
+{% for priv in data.deffuncacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for types ###}
+{% if data.deftypeacl %}
+{% if 'deleted' in data.deftypeacl %}
+{% for priv in data.deftypeacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deftypeacl %}
+{% for priv in data.deftypeacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deftypeacl %}
+{% for priv in data.deftypeacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{###  End main if data ###}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/acl.sql
new file mode 100644
index 0000000..5121270
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/acl.sql
@@ -0,0 +1,54 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/alter.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/alter.sql
new file mode 100644
index 0000000..a5c2bd5
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/alter.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{###  To alter description ###}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Security Labels on schema ###}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% for r in data.seclabels %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+
+{% endif %}
+{###  ACL on schema ###}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+
+{% endif %}
+{### End of main if ###}
+{% endif %}
+{# ======== Below SQL will fetch id for given dataspace ======== #}
+{% if schema %}
+SELECT nsp.oid FROM pg_namespace nsp WHERE nsp.nspname = {{schema|qtLiteral}};
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/create.sql
new file mode 100644
index 0000000..96bc4e6
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/create.sql
@@ -0,0 +1,6 @@
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}{% if data.namespaceowner %}
+
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }}{% endif %};
+{% endif %}
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/defacl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/defacl.sql
new file mode 100644
index 0000000..4167168
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/defacl.sql
@@ -0,0 +1,39 @@
+SELECT
+	CASE (a.deftype)
+	WHEN 'r' THEN 'deftblacl'
+	WHEN 'S' THEN 'defseqacl'
+	WHEN 'f' THEN 'deffuncacl'
+	WHEN 'T' THEN 'deftypeacl'
+	END AS deftype,
+	COALESCE(gt.rolname, 'public') grantee, g.rolname grantor, array_agg(a.privilege_type) as privileges, array_agg(a.is_grantable) as grantable
+FROM
+	(SELECT
+		(acl).grantee as grantee, (acl).grantor AS grantor, (acl).is_grantable AS is_grantable,
+		CASE (acl).privilege_type
+		WHEN 'CONNECT' THEN 'c'
+		WHEN 'CREATE' THEN 'C'
+		WHEN 'DELETE' THEN 'd'
+		WHEN 'EXECUTE' THEN 'X'
+		WHEN 'INSERT' THEN 'a'
+		WHEN 'REFERENCES' THEN 'x'
+		WHEN 'SELECT' THEN 'r'
+		WHEN 'TEMPORARY' THEN 'T'
+		WHEN 'TRIGGER' THEN 't'
+		WHEN 'TRUNCATE' THEN 'D'
+		WHEN 'UPDATE' THEN 'w'
+		WHEN 'USAGE' THEN 'U'
+		ELSE 'UNKNOWN'
+		END AS privilege_type,
+		defaclobjtype as deftype
+	FROM
+		(SELECT defaclobjtype, aclexplode(defaclacl) as acl
+			FROM
+				pg_namespace nsp
+				LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+			WHERE
+				nsp.oid={{scid}}::int
+        ) d) a
+	LEFT JOIN pg_catalog.pg_roles g ON (a.grantor = g.oid)
+	LEFT JOIN pg_catalog.pg_roles gt ON (a.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname, a.deftype
+ORDER BY a.deftype
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/delete.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/delete.sql
new file mode 100644
index 0000000..7686040
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/delete.sql
@@ -0,0 +1,8 @@
+{% if scid %}
+SELECT nsp.nspname as name, nsp.oid
+FROM pg_namespace nsp
+WHERE nsp.oid = {{scid}};
+{% endif %}
+{% if name %}
+DROP SCHEMA {{ conn|qtIdent(name) }} {% if cascade %}CASCADE{%endif%};
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/properties.sql
new file mode 100644
index 0000000..7a10828
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/properties.sql
@@ -0,0 +1,33 @@
+SELECT
+	CASE
+	WHEN (nspname LIKE E'pg\\\\_temp\\\\_%') THEN 1
+	WHEN (nspname LIKE E'pg\\\\_%') THEN 0
+	ELSE 3 END
+	AS nsptyp,
+	nsp.nspname as name, nsp.oid,
+	pg_get_userbyid(nspowner) AS namespaceowner, nspacl, description,
+	has_schema_privilege(nsp.oid, 'CREATE') as cancreate,
+	CASE WHEN nspname LIKE E'pg\\_%' THEN true ELSE false END as is_sys_object,
+	(SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM
+	pg_namespace nsp
+	LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+WHERE
+	NOT ((nspname = 'pg_catalog' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'pgagent' AND EXISTS
+	(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'information_schema' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'dbo' OR nspname = 'sys')
+	)AND
+	{% if scid %}
+	nsp.oid={{scid}}::int AND
+	{% endif %}
+	nspname NOT LIKE E'pg\\temp\\%' AND
+	nspname NOT LIKE E'pg\\toast_temp\\%' AND
+	nsp.nspparent = 0 AND NOT
+		(nspname = 'dbms_job_procedure' AND EXISTS(SELECT 1 FROM pg_proc WHERE pronamespace = nsp.oid and proname = 'run_job' LIMIT 1))
+ORDER BY 1, nspname;
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/update.sql
new file mode 100644
index 0000000..fe3fcad
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.1_plus/update.sql
@@ -0,0 +1,125 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{### To update SCHEMA name ###}
+{% if data.name and data.name != o_data.name %}
+ALTER SCHEMA {{ conn|qtIdent(o_data.name) }}
+  RENAME TO {{ conn|qtIdent(data.name) }};
+
+{% endif %}
+{### To update SCHEMA owner ###}
+{% if data.namespaceowner and data.namespaceowner != o_data.namespaceowner %}
+ALTER SCHEMA {{ conn|qtIdent(data.name) }}
+  OWNER TO {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{### To update SCHEMA comments ###}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Change the security labels ###}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### Change the privileges ###}
+{% if data.nspacl %}
+{% if 'deleted' in data.nspacl %}
+{% for priv in data.nspacl.deleted %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.nspacl %}
+{% for priv in data.nspacl.changed %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.nspacl %}
+{% for priv in data.nspacl.added %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for tables ###}
+{% if data.deftblacl %}
+{% if 'deleted' in data.deftblacl %}
+{% for priv in data.deftblacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deftblacl %}
+{% for priv in data.deftblacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deftblacl %}
+{% for priv in data.deftblacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for sequences ###}
+{% if data.defseqacl %}
+{% if 'deleted' in data.defseqacl %}
+{% for priv in data.defseqacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.defseqacl %}
+{% for priv in data.defseqacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.defseqacl %}
+{% for priv in data.defseqacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for functions ###}
+{% if data.deffuncacl %}
+{% if 'deleted' in data.deffuncacl %}
+{% for priv in data.deffuncacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deffuncacl %}
+{% for priv in data.deffuncacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deffuncacl %}
+{% for priv in data.deffuncacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{###  End main if data ###}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/acl.sql
new file mode 100644
index 0000000..5121270
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/acl.sql
@@ -0,0 +1,54 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/alter.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/alter.sql
new file mode 100644
index 0000000..a5c2bd5
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/alter.sql
@@ -0,0 +1,30 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{###  To alter description ###}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Security Labels on schema ###}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% for r in data.seclabels %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+
+{% endif %}
+{###  ACL on schema ###}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+
+{% endif %}
+{### End of main if ###}
+{% endif %}
+{# ======== Below SQL will fetch id for given dataspace ======== #}
+{% if schema %}
+SELECT nsp.oid FROM pg_namespace nsp WHERE nsp.nspname = {{schema|qtLiteral}};
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/create.sql
new file mode 100644
index 0000000..96bc4e6
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/create.sql
@@ -0,0 +1,6 @@
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}{% if data.namespaceowner %}
+
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }}{% endif %};
+{% endif %}
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/defacl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/defacl.sql
new file mode 100644
index 0000000..4167168
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/defacl.sql
@@ -0,0 +1,39 @@
+SELECT
+	CASE (a.deftype)
+	WHEN 'r' THEN 'deftblacl'
+	WHEN 'S' THEN 'defseqacl'
+	WHEN 'f' THEN 'deffuncacl'
+	WHEN 'T' THEN 'deftypeacl'
+	END AS deftype,
+	COALESCE(gt.rolname, 'public') grantee, g.rolname grantor, array_agg(a.privilege_type) as privileges, array_agg(a.is_grantable) as grantable
+FROM
+	(SELECT
+		(acl).grantee as grantee, (acl).grantor AS grantor, (acl).is_grantable AS is_grantable,
+		CASE (acl).privilege_type
+		WHEN 'CONNECT' THEN 'c'
+		WHEN 'CREATE' THEN 'C'
+		WHEN 'DELETE' THEN 'd'
+		WHEN 'EXECUTE' THEN 'X'
+		WHEN 'INSERT' THEN 'a'
+		WHEN 'REFERENCES' THEN 'x'
+		WHEN 'SELECT' THEN 'r'
+		WHEN 'TEMPORARY' THEN 'T'
+		WHEN 'TRIGGER' THEN 't'
+		WHEN 'TRUNCATE' THEN 'D'
+		WHEN 'UPDATE' THEN 'w'
+		WHEN 'USAGE' THEN 'U'
+		ELSE 'UNKNOWN'
+		END AS privilege_type,
+		defaclobjtype as deftype
+	FROM
+		(SELECT defaclobjtype, aclexplode(defaclacl) as acl
+			FROM
+				pg_namespace nsp
+				LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+			WHERE
+				nsp.oid={{scid}}::int
+        ) d) a
+	LEFT JOIN pg_catalog.pg_roles g ON (a.grantor = g.oid)
+	LEFT JOIN pg_catalog.pg_roles gt ON (a.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname, a.deftype
+ORDER BY a.deftype
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/delete.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/delete.sql
new file mode 100644
index 0000000..7686040
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/delete.sql
@@ -0,0 +1,8 @@
+{% if scid %}
+SELECT nsp.nspname as name, nsp.oid
+FROM pg_namespace nsp
+WHERE nsp.oid = {{scid}};
+{% endif %}
+{% if name %}
+DROP SCHEMA {{ conn|qtIdent(name) }} {% if cascade %}CASCADE{%endif%};
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/properties.sql
new file mode 100644
index 0000000..f5a51a4
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/properties.sql
@@ -0,0 +1,35 @@
+SELECT
+	CASE
+	WHEN (nspname LIKE E'pg\\\\_temp\\\\_%') THEN 1
+	WHEN (nspname LIKE E'pg\\\\_%') THEN 0
+	ELSE 3 END
+	AS nsptyp,
+	nsp.nspname as name, nsp.oid,
+	pg_get_userbyid(nspowner) AS namespaceowner, nspacl, description,
+	has_schema_privilege(nsp.oid, 'CREATE') as cancreate,
+	CASE WHEN nspname LIKE E'pg\\_%' THEN true ELSE false END as is_sys_object,
+	(SELECT array_agg(provider || '=' || label) FROM pg_shseclabel sl1 WHERE sl1.objoid=nsp.oid) AS seclabels
+FROM
+	pg_namespace nsp
+	LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+WHERE
+	NOT ((nspname = 'pg_catalog' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'pgagent' AND EXISTS
+	(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'information_schema' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'dbo' OR nspname = 'sys')
+	)AND
+	{% if scid %}
+	nsp.oid={{scid}}::int AND
+	{% endif %}
+	nspname NOT LIKE E'pg\\temp\\%' AND
+	nspname NOT LIKE E'pg\\toast_temp\\%' AND
+	nsp.nspparent = 0 AND NOT
+		(nspname = 'dbms_job_procedure' AND EXISTS(SELECT 1 FROM pg_proc WHERE pronamespace = nsp.oid and proname = 'run_job' LIMIT 1))
+ORDER BY 1, nspname;
+
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/update.sql
new file mode 100644
index 0000000..d8bc687
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_9.2_plus/update.sql
@@ -0,0 +1,145 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{### To update SCHEMA name ###}
+{% if data.name and data.name != o_data.name %}
+ALTER SCHEMA {{ conn|qtIdent(o_data.name) }}
+  RENAME TO {{ conn|qtIdent(data.name) }};
+
+{% endif %}
+{### To update SCHEMA owner ###}
+{% if data.namespaceowner and data.namespaceowner != o_data.namespaceowner %}
+ALTER SCHEMA {{ conn|qtIdent(data.name) }}
+  OWNER TO {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{### To update SCHEMA comments ###}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Change the security labels ###}
+{# The SQL generated below will change Security Label #}
+{% if data.seclabels and data.seclabels|length > 0 %}
+{% set seclabels = data.seclabels %}
+{% if 'deleted' in seclabels and seclabels.deleted|length > 0 %}
+{% for r in seclabels.deleted %}
+{{ SECLABLE.DROP(conn, 'SCHEMA', data.name, r.provider) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in seclabels and seclabels.added|length > 0 %}
+{% for r in seclabels.added %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in seclabels and seclabels.changed|length > 0 %}
+{% for r in seclabels.changed %}
+{{ SECLABLE.APPLY(conn, 'SCHEMA', data.name, r.provider, r.security_label) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### Change the privileges ###}
+{% if data.nspacl %}
+{% if 'deleted' in data.nspacl %}
+{% for priv in data.nspacl.deleted %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.nspacl %}
+{% for priv in data.nspacl.changed %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.nspacl %}
+{% for priv in data.nspacl.added %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for tables ###}
+{% if data.deftblacl %}
+{% if 'deleted' in data.deftblacl %}
+{% for priv in data.deftblacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deftblacl %}
+{% for priv in data.deftblacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn, 'SCHEMA', data.name, 'TABLES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deftblacl %}
+{% for priv in data.deftblacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TABLES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for sequences ###}
+{% if data.defseqacl %}
+{% if 'deleted' in data.defseqacl %}
+{% for priv in data.defseqacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.defseqacl %}
+{% for priv in data.defseqacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.defseqacl %}
+{% for priv in data.defseqacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'SEQUENCES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for functions ###}
+{% if data.deffuncacl %}
+{% if 'deleted' in data.deffuncacl %}
+{% for priv in data.deffuncacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deffuncacl %}
+{% for priv in data.deffuncacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deffuncacl %}
+{% for priv in data.deffuncacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'FUNCTIONS', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{### To change default privileges for types ###}
+{% if data.deftypeacl %}
+{% if 'deleted' in data.deftypeacl %}
+{% for priv in data.deftypeacl.deleted %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.deftypeacl %}
+{% for priv in data.deftypeacl.changed %}
+{{ DEFAULT_PRIVILEGE.UNSET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee) }}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.deftypeacl %}
+{% for priv in data.deftypeacl.added %}
+{{ DEFAULT_PRIVILEGE.SET(conn,'SCHEMA', data.name, 'TYPES', priv.grantee, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{###  End main if data ###}
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/acl.sql
new file mode 100644
index 0000000..5121270
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/acl.sql
@@ -0,0 +1,54 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/alter.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/alter.sql
new file mode 100644
index 0000000..ee0e591
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/alter.sql
@@ -0,0 +1,21 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+{###  To alter description ###}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{###  ACL on schema ###}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+
+{% endif %}
+{### End of main if ###}
+{% endif %}
+{# ======== Below SQL will fetch id for given dataspace ======== #}
+{% if schema %}
+SELECT nsp.oid FROM pg_namespace nsp WHERE nsp.nspname = {{schema|qtLiteral}};
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/create.sql
new file mode 100644
index 0000000..96bc4e6
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/create.sql
@@ -0,0 +1,6 @@
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}{% if data.namespaceowner %}
+
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }}{% endif %};
+{% endif %}
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/defacl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/defacl.sql
new file mode 100644
index 0000000..4167168
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/defacl.sql
@@ -0,0 +1,39 @@
+SELECT
+	CASE (a.deftype)
+	WHEN 'r' THEN 'deftblacl'
+	WHEN 'S' THEN 'defseqacl'
+	WHEN 'f' THEN 'deffuncacl'
+	WHEN 'T' THEN 'deftypeacl'
+	END AS deftype,
+	COALESCE(gt.rolname, 'public') grantee, g.rolname grantor, array_agg(a.privilege_type) as privileges, array_agg(a.is_grantable) as grantable
+FROM
+	(SELECT
+		(acl).grantee as grantee, (acl).grantor AS grantor, (acl).is_grantable AS is_grantable,
+		CASE (acl).privilege_type
+		WHEN 'CONNECT' THEN 'c'
+		WHEN 'CREATE' THEN 'C'
+		WHEN 'DELETE' THEN 'd'
+		WHEN 'EXECUTE' THEN 'X'
+		WHEN 'INSERT' THEN 'a'
+		WHEN 'REFERENCES' THEN 'x'
+		WHEN 'SELECT' THEN 'r'
+		WHEN 'TEMPORARY' THEN 'T'
+		WHEN 'TRIGGER' THEN 't'
+		WHEN 'TRUNCATE' THEN 'D'
+		WHEN 'UPDATE' THEN 'w'
+		WHEN 'USAGE' THEN 'U'
+		ELSE 'UNKNOWN'
+		END AS privilege_type,
+		defaclobjtype as deftype
+	FROM
+		(SELECT defaclobjtype, aclexplode(defaclacl) as acl
+			FROM
+				pg_namespace nsp
+				LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+			WHERE
+				nsp.oid={{scid}}::int
+        ) d) a
+	LEFT JOIN pg_catalog.pg_roles g ON (a.grantor = g.oid)
+	LEFT JOIN pg_catalog.pg_roles gt ON (a.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname, a.deftype
+ORDER BY a.deftype
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/delete.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/delete.sql
new file mode 100644
index 0000000..7686040
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/delete.sql
@@ -0,0 +1,8 @@
+{% if scid %}
+SELECT nsp.nspname as name, nsp.oid
+FROM pg_namespace nsp
+WHERE nsp.oid = {{scid}};
+{% endif %}
+{% if name %}
+DROP SCHEMA {{ conn|qtIdent(name) }} {% if cascade %}CASCADE{%endif%};
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/properties.sql
new file mode 100644
index 0000000..18edf06
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/properties.sql
@@ -0,0 +1,32 @@
+SELECT
+	CASE
+	WHEN (nspname LIKE E'pg\\\\_temp\\\\_%') THEN 1
+	WHEN (nspname LIKE E'pg\\\\_%') THEN 0
+	ELSE 3 END
+	AS nsptyp,
+	nsp.nspname as name, nsp.oid,
+	pg_get_userbyid(nspowner) AS namespaceowner, nspacl, description,
+	has_schema_privilege(nsp.oid, 'CREATE') as cancreate,
+	CASE WHEN nspname LIKE E'pg\\_%' THEN true ELSE false END as is_sys_object,
+FROM
+	pg_namespace nsp
+	LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+WHERE
+	NOT ((nspname = 'pg_catalog' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'pgagent' AND EXISTS
+	(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'information_schema' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'dbo' OR nspname = 'sys')
+	)AND
+	{% if scid %}
+	nsp.oid={{scid}}::int AND
+	{% endif %}
+	nspname NOT LIKE E'pg\\temp\\%' AND
+	nspname NOT LIKE E'pg\\toast_temp\\%' AND
+	nsp.nspparent = 0 AND NOT
+		(nspname = 'dbms_job_procedure' AND EXISTS(SELECT 1 FROM pg_proc WHERE pronamespace = nsp.oid and proname = 'run_job' LIMIT 1))
+ORDER BY 1, nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/update.sql
new file mode 100644
index 0000000..4fea7ca
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/edb_pre_9.1/update.sql
@@ -0,0 +1,42 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+{### To update SCHEMA name ###}
+{% if data.name and data.name != o_data.name %}
+ALTER SCHEMA {{ conn|qtIdent(o_data.name) }}
+  RENAME TO {{ conn|qtIdent(data.name) }};
+
+{% endif %}
+{### To update SCHEMA owner ###}
+{% if data.namespaceowner and data.namespaceowner != o_data.namespaceowner %}
+ALTER SCHEMA {{ conn|qtIdent(data.name) }}
+  OWNER TO {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{### To update SCHEMA comments ###}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Change the privileges ###}
+{% if data.nspacl %}
+{% if 'deleted' in data.nspacl %}
+{% for priv in data.nspacl.deleted %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.nspacl %}
+{% for priv in data.nspacl.changed %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.nspacl %}
+{% for priv in data.nspacl.added %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{###  End main if data ###}
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/acl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/acl.sql
new file mode 100644
index 0000000..5121270
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/acl.sql
@@ -0,0 +1,54 @@
+{### SQL to fetch privileges for catalog ###}
+SELECT 'nspacl' as deftype, COALESCE(gt.rolname, 'public') grantee, g.rolname grantor,
+    array_agg(privilege_type) as privileges, array_agg(is_grantable) as grantable
+FROM
+  (SELECT
+    d.grantee, d.grantor, d.is_grantable,
+    CASE d.privilege_type
+    WHEN 'CREATE' THEN 'C'
+    WHEN 'USAGE' THEN 'U'
+    ELSE 'UNKNOWN'
+    END AS privilege_type
+  FROM
+    ( SELECT nsp.nspacl
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+    ) acl,
+    (SELECT (d).grantee AS grantee, (d).grantor AS grantor, (d).is_grantable
+        AS is_grantable, (d).privilege_type AS privilege_type FROM (SELECT
+        aclexplode(nsp.nspacl) as d
+FROM pg_namespace nsp
+LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+WHERE
+NOT ((nspname = 'pg_catalog' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'pgagent' AND EXISTS
+(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname = 'information_schema' AND EXISTS
+  (SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+(nspname LIKE '_%' AND EXISTS
+                             (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+)AND
+nsp.oid={{scid}}::int AND
+nspname NOT LIKE E'pg\\temp\\%' AND
+nspname NOT LIKE E'pg\\toast_temp\\%'
+        ) a) d
+    ) d
+  LEFT JOIN pg_catalog.pg_roles g ON (d.grantor = g.oid)
+  LEFT JOIN pg_catalog.pg_roles gt ON (d.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/alter.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/alter.sql
new file mode 100644
index 0000000..3de22bb
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/alter.sql
@@ -0,0 +1,23 @@
+{% import 'macros/security.macros' as SECLABLE %}
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% import 'macros/default_privilege.macros' as DEFAULT_PRIVILEGE %}
+{% if data %}
+{###  To alter description ###}
+{% if data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{###  ACL on schema ###}
+{% if data.nspacl %}
+{% for priv in data.nspacl %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+
+{% endif %}
+{### End of main if ###}
+{% endif %}
+{# ======== Below SQL will fetch id for given dataspace ======== #}
+{% if schema %}
+SELECT nsp.oid FROM pg_namespace nsp WHERE nsp.nspname = {{schema|qtLiteral}};
+{% endif %}
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/create.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/create.sql
new file mode 100644
index 0000000..96bc4e6
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/create.sql
@@ -0,0 +1,6 @@
+{% if data %}
+CREATE SCHEMA {{ conn|qtIdent(data.name) }}{% if data.namespaceowner %}
+
+  AUTHORIZATION {{ conn|qtIdent(data.namespaceowner) }}{% endif %};
+{% endif %}
+
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/defacl.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/defacl.sql
new file mode 100644
index 0000000..4167168
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/defacl.sql
@@ -0,0 +1,39 @@
+SELECT
+	CASE (a.deftype)
+	WHEN 'r' THEN 'deftblacl'
+	WHEN 'S' THEN 'defseqacl'
+	WHEN 'f' THEN 'deffuncacl'
+	WHEN 'T' THEN 'deftypeacl'
+	END AS deftype,
+	COALESCE(gt.rolname, 'public') grantee, g.rolname grantor, array_agg(a.privilege_type) as privileges, array_agg(a.is_grantable) as grantable
+FROM
+	(SELECT
+		(acl).grantee as grantee, (acl).grantor AS grantor, (acl).is_grantable AS is_grantable,
+		CASE (acl).privilege_type
+		WHEN 'CONNECT' THEN 'c'
+		WHEN 'CREATE' THEN 'C'
+		WHEN 'DELETE' THEN 'd'
+		WHEN 'EXECUTE' THEN 'X'
+		WHEN 'INSERT' THEN 'a'
+		WHEN 'REFERENCES' THEN 'x'
+		WHEN 'SELECT' THEN 'r'
+		WHEN 'TEMPORARY' THEN 'T'
+		WHEN 'TRIGGER' THEN 't'
+		WHEN 'TRUNCATE' THEN 'D'
+		WHEN 'UPDATE' THEN 'w'
+		WHEN 'USAGE' THEN 'U'
+		ELSE 'UNKNOWN'
+		END AS privilege_type,
+		defaclobjtype as deftype
+	FROM
+		(SELECT defaclobjtype, aclexplode(defaclacl) as acl
+			FROM
+				pg_namespace nsp
+				LEFT OUTER JOIN pg_catalog.pg_default_acl dacl ON (dacl.defaclnamespace = nsp.oid)
+			WHERE
+				nsp.oid={{scid}}::int
+        ) d) a
+	LEFT JOIN pg_catalog.pg_roles g ON (a.grantor = g.oid)
+	LEFT JOIN pg_catalog.pg_roles gt ON (a.grantee = gt.oid)
+GROUP BY g.rolname, gt.rolname, a.deftype
+ORDER BY a.deftype
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/delete.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/delete.sql
new file mode 100644
index 0000000..7686040
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/delete.sql
@@ -0,0 +1,8 @@
+{% if scid %}
+SELECT nsp.nspname as name, nsp.oid
+FROM pg_namespace nsp
+WHERE nsp.oid = {{scid}};
+{% endif %}
+{% if name %}
+DROP SCHEMA {{ conn|qtIdent(name) }} {% if cascade %}CASCADE{%endif%};
+{% endif %}
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/properties.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/properties.sql
new file mode 100644
index 0000000..7c550b5
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/properties.sql
@@ -0,0 +1,29 @@
+SELECT
+	CASE
+	WHEN (nspname LIKE E'pg\\\\_temp\\\\_%') THEN 1
+	WHEN (nspname LIKE E'pg\\\\_%') THEN 0
+	ELSE 3 END
+	AS nsptyp,
+	nsp.nspname as name, nsp.oid,
+	pg_get_userbyid(nspowner) AS namespaceowner, description,
+	has_schema_privilege(nsp.oid, 'CREATE') as cancreate,
+	CASE WHEN nspname LIKE E'pg\\_%' THEN true ELSE false END as is_sys_object,
+FROM
+	pg_namespace nsp
+	LEFT OUTER JOIN pg_description des ON (des.objoid=nsp.oid AND des.classoid='pg_namespace'::regclass)
+WHERE
+	NOT ((nspname = 'pg_catalog' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'pg_class' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'pgagent' AND EXISTS
+	(SELECT 1 FROM pg_class WHERE relname = 'pga_job' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname = 'information_schema' AND EXISTS
+		(SELECT 1 FROM pg_class WHERE relname = 'tables' AND relnamespace = nsp.oid LIMIT 1)) OR
+	(nspname LIKE '_%' AND EXISTS
+                               (SELECT 1 FROM pg_proc WHERE proname='slonyversion' AND pronamespace = nsp.oid LIMIT 1))
+	)AND
+	{% if scid %}
+	nsp.oid={{scid}}::int AND
+	{% endif %}
+	nspname NOT LIKE E'pg\\temp\\%' AND
+	nspname NOT LIKE E'pg\\toast_temp\\%'
+ORDER BY 1, nspname;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/update.sql
new file mode 100644
index 0000000..31c04be
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/templates/schemas/sql/pre_9.1/update.sql
@@ -0,0 +1,42 @@
+{% import 'macros/privilege.macros' as PRIVILEGE %}
+{% if data %}
+{### To update SCHEMA name ###}
+{% if data.name and data.name != o_data.name %}
+ALTER SCHEMA {{ conn|qtIdent(o_data.name) }}
+  RENAME TO {{ conn|qtIdent(data.name) }};
+
+{% endif %}
+{### To update SCHEMA owner ###}
+{% if data.namespaceowner and data.namespaceowner != o_data.namespaceowner %}
+ALTER SCHEMA {{ conn|qtIdent(data.name) }}
+  OWNER TO {{ conn|qtIdent(data.namespaceowner) }};
+
+{% endif %}
+{### To update SCHEMA comments ###}
+{% if data.description and data.description != o_data.description %}
+COMMENT ON SCHEMA {{ conn|qtIdent(data.name) }}
+  IS {{ data.description|qtLiteral }};
+
+{% endif %}
+{### Change the privileges ###}
+{% if data.nspacl %}
+{% if 'deleted' in data.nspacl %}
+{% for priv in data.nspacl.deleted %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{% endfor %}
+{% endif %}
+{% if 'changed' in data.nspacl %}
+{% for priv in data.nspacl.changed %}
+{{ PRIVILEGE.RESETALL(conn, 'SCHEMA', priv.grantee, data.name) }}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+{% if 'added' in data.nspacl %}
+{% for priv in data.nspacl.added %}
+{{ PRIVILEGE.APPLY(conn, 'SCHEMA', priv.grantee, data.name, priv.without_grant, priv.with_grant) }}
+{% endfor %}
+{% endif %}
+
+{% endif %}
+{###  End main if data ###}
+{% endif %}
